codex

package
v0.43.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 30, 2026 License: MIT Imports: 18 Imported by: 0

Documentation

Overview

Package codex implements the Codex platform adapter.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Adapter

type Adapter struct {
	// contains filtered or unexported fields
}

Adapter is the Codex platform adapter.

func New

func New() *Adapter

New creates an adapter rooted at the current directory.

func NewWithRoot

func NewWithRoot(root string) *Adapter

NewWithRoot creates an adapter rooted at the specified path.

func (*Adapter) CLIBinary

func (a *Adapter) CLIBinary() string

func (*Adapter) Clean

func (a *Adapter) Clean(_ context.Context) error

Clean removes files created by this adapter.

func (*Adapter) Detect

func (a *Adapter) Detect(_ context.Context) (bool, error)

Detect checks whether the codex binary is installed in PATH.

func (*Adapter) Generate

Generate creates Codex platform files based on harness config.

func (*Adapter) InstallHooks

func (a *Adapter) InstallHooks(_ context.Context, _ []adapter.HookConfig, _ *adapter.PermissionSet) error

InstallHooks is a no-op — hooks are managed via .codex/hooks.json template.

func (*Adapter) Name

func (a *Adapter) Name() string

func (*Adapter) SupportsHooks

func (a *Adapter) SupportsHooks() bool

SupportsHooks returns true. Codex supports hooks via .codex/hooks.json.

func (*Adapter) Update

Update updates files based on manifest diff.

func (*Adapter) Validate

func (a *Adapter) Validate(_ context.Context) ([]adapter.ValidationError, error)

Validate checks the validity of installed files.

func (*Adapter) Version

func (a *Adapter) Version() string

Jump to