Documentation
¶
Overview ¶
Package codex implements the Codex platform adapter.
Index ¶
- type Adapter
- func (a *Adapter) CLIBinary() string
- func (a *Adapter) Clean(_ context.Context) error
- func (a *Adapter) Detect(_ context.Context) (bool, error)
- func (a *Adapter) Generate(_ context.Context, cfg *config.HarnessConfig) (*adapter.PlatformFiles, error)
- func (a *Adapter) InstallHooks(_ context.Context, _ []adapter.HookConfig, _ *adapter.PermissionSet) error
- func (a *Adapter) Name() string
- func (a *Adapter) SupportsHooks() bool
- func (a *Adapter) Update(ctx context.Context, cfg *config.HarnessConfig) (*adapter.PlatformFiles, error)
- func (a *Adapter) Validate(_ context.Context) ([]adapter.ValidationError, error)
- func (a *Adapter) Version() string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Adapter ¶
type Adapter struct {
// contains filtered or unexported fields
}
Adapter is the Codex platform adapter.
func NewWithRoot ¶
NewWithRoot creates an adapter rooted at the specified path.
func (*Adapter) Generate ¶
func (a *Adapter) Generate(_ context.Context, cfg *config.HarnessConfig) (*adapter.PlatformFiles, error)
Generate creates Codex platform files based on harness config.
func (*Adapter) InstallHooks ¶
func (a *Adapter) InstallHooks(_ context.Context, _ []adapter.HookConfig, _ *adapter.PermissionSet) error
InstallHooks is a no-op — hooks are managed via .codex/hooks.json template.
func (*Adapter) SupportsHooks ¶
SupportsHooks returns true. Codex supports hooks via .codex/hooks.json.
func (*Adapter) Update ¶
func (a *Adapter) Update(ctx context.Context, cfg *config.HarnessConfig) (*adapter.PlatformFiles, error)
Update updates files based on manifest diff.
Source Files
¶
- codex.go
- codex_agents.go
- codex_config_merge.go
- codex_config_validate.go
- codex_context_docs.go
- codex_extended_skill_rewrites.go
- codex_extended_skill_rewrites_agents.go
- codex_extended_skill_rewrites_worktree.go
- codex_extended_skills.go
- codex_hooks.go
- codex_lifecycle.go
- codex_marker.go
- codex_plugin_manifest.go
- codex_prepare_files.go
- codex_prompts.go
- codex_rules.go
- codex_settings.go
- codex_skill_render.go
- codex_skill_template_mappings.go
- codex_skills.go
- codex_standard_skills.go
- codex_surface_cleanup.go
- codex_workflow_custom.go
- codex_workflow_specs.go
Click to show internal directories.
Click to hide internal directories.