Documentation
¶
Overview ¶
Package opencode implements the OpenCode platform adapter.
Index ¶
- type Adapter
- func (a *Adapter) CLIBinary() string
- func (a *Adapter) Clean(_ context.Context) error
- func (a *Adapter) Detect(_ context.Context) (bool, error)
- func (a *Adapter) Generate(ctx context.Context, cfg *config.HarnessConfig) (*adapter.PlatformFiles, error)
- func (a *Adapter) InjectOrchestraPlugin(scriptPath string) error
- func (a *Adapter) InstallHooks(_ context.Context, hooks []adapter.HookConfig, _ *adapter.PermissionSet) error
- func (a *Adapter) Name() string
- func (a *Adapter) SupportsHooks() bool
- func (a *Adapter) Update(ctx context.Context, cfg *config.HarnessConfig) (*adapter.PlatformFiles, error)
- func (a *Adapter) Validate(_ context.Context) ([]adapter.ValidationError, error)
- func (a *Adapter) Version() string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Adapter ¶
type Adapter struct {
// contains filtered or unexported fields
}
Adapter is the OpenCode platform adapter.
func NewWithRoot ¶
NewWithRoot creates an adapter rooted at the specified path.
func (*Adapter) Generate ¶
func (a *Adapter) Generate(ctx context.Context, cfg *config.HarnessConfig) (*adapter.PlatformFiles, error)
Generate creates OpenCode platform files based on the harness config.
func (*Adapter) InjectOrchestraPlugin ¶
InjectOrchestraPlugin preserves legacy external callers by appending a plugin path.
func (*Adapter) InstallHooks ¶
func (a *Adapter) InstallHooks(_ context.Context, hooks []adapter.HookConfig, _ *adapter.PermissionSet) error
InstallHooks updates OpenCode plugin wiring for the provided hooks.
func (*Adapter) SupportsHooks ¶
func (*Adapter) Update ¶
func (a *Adapter) Update(ctx context.Context, cfg *config.HarnessConfig) (*adapter.PlatformFiles, error)
Update updates OpenCode files based on the manifest diff.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.